--- debhelper-5.0.62/dh_compress 
+++ debhelper-5.0.62.new/dh_compress 
@@ -58,6 +58,13 @@
 
 =back
 
+=head1 NOTES
+
+If the DEB_BUILD_OPTIONS environment variable contains "nodocs",
+debian/copyright is not excluded from compression.
+
+=cut
+
 =head1 CONFORMS TO
 
 Debian policy, version 3.0
@@ -88,21 +95,32 @@
 		push @files, split(/\n/,`sh $olddir/$compress 2>/dev/null`);
 	}
 	else {
-		# Note that all the excludes of odd things like _z 
+		# if nodocs is used, allow compression of debian/copyright
+		my $nodocs=qq/! -name "copyright"/;
+		$nodocs="" if (defined $ENV{DEB_BUILD_OPTIONS} && $ENV{DEB_BUILD_OPTIONS} =~ /nodocs/);
+		# also allow compression of sub 4k copyright files for
+		# embedded filesystems with smaller block/page sizes.
+		my $omitsmall=qq/-size +4k -or/;
+		$omitsmall="" if (defined $ENV{DEB_BUILD_OPTIONS} && $ENV{DEB_BUILD_OPTIONS} =~ /nodocs/);
+		# find needs -name before ! -name, so add the copyright file
+		# at the start of the find command.
+		my $addcopy="";
+		$addcopy=qq/ -name "copyright" -or/ if (defined $ENV{DEB_BUILD_OPTIONS} && $ENV{DEB_BUILD_OPTIONS} =~ /nodocs/);
+		# Note that all the excludes of odd things like _z
 		# are because gzip refuses to compress such files, assumming
 		# they are zip files. I looked at the gzip source to get the
 		# complete list of such extensions: ".gz", ".z", ".taz", 
 		# ".tgz", "-gz", "-z", "_z"
 		push @files, split(/\n/,`
 			find usr/info usr/share/info usr/man usr/share/man usr/X11*/man -type f ! -name "*.gz" 2>/dev/null || true;
-			find usr/share/doc -type f \\( -size +4k -or -name "changelog*" -or -name "NEWS*" \\) \\
+			find usr/share/doc -type f \\( $omitsmall $addcopy -name "changelog*" -or -name "NEWS*" \\) \\
 				\\( -name changelog.html -or ! -iname "*.htm*" \\) \\
 				! -iname "*.gif" ! -iname "*.png" ! -iname "*.jpg" \\
 				! -iname "*.jpeg" ! -iname "*.gz" ! -iname "*.taz" \\
 				! -iname "*.tgz" ! -iname "*.z" ! -iname "*.bz2" \\
 				! -iname "*-gz"  ! -iname "*-z" ! -iname "*_z" \\
 				! -iname "*.jar" ! -iname "*.zip" ! -iname "*.css" \\
-				! -name "copyright" 2>/dev/null || true;
+				$nodocs 2>/dev/null || true;
 			find usr/X11R6/lib/X11/fonts usr/share/fonts/X11 -type f -name "*.pcf" 2>/dev/null || true;
 		`);
 	}
